@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 Agathe Porte <microjoe@microjoe.org>
+//
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 use gio::prelude::*;
 use gtk::prelude::*;
 use gtk_liststore_item::ListStoreItem;
@@ -8,7 +12,6 @@ use gladis::Gladis;
 struct Ui {
     window: gtk::Window,
     list_store: gtk::ListStore,
-    tree_view: gtk::TreeView,
 }
 
 #[derive(ListStoreItem)]
